Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(427)

Unified Diff: chrome/common/chrome_switches.cc

Issue 21150006: Introduce --cancel-first-run and reduce the strength of --no-first-run. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: --skip-first-run => --no-first-run Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/installer/setup/setup_main.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_switches.cc
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index d3d5d24a5cb95dccbcc61dc3c6d7c2fe468f6a24..383251513aceb8dc2998c61460f9cee385ae03cb 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -145,6 +145,10 @@ const char kAutomationClientChannelID[] = "automation-channel";
const char kAutomationReinitializeOnChannelError[] =
"automation-reinitialize-on-channel-error";
+// Similar to kNoFirstRun, but also drops the First Run beacon so that first run
+// will not occur in subsequent runs either.
+const char kCancelFirstRun[] = "cancel-first-run";
+
// How often (in seconds) to check for updates. Should only be used for testing
// purposes.
const char kCheckForUpdateIntervalSec[] = "check-for-update-interval";
@@ -809,7 +813,8 @@ const char kFileDescriptorLimit[] = "file-descriptor-limit";
const char kForceAppMode[] = "force-app-mode";
// Displays the First Run experience when the browser is started, regardless of
// whether or not it's actually the First Run (this overrides kNoFirstRun).
const char kForceFirstRun[] = "force-first-run";
// Tries to load cloud policy for every signed in user, regardless of whether
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/installer/setup/setup_main.cc » ('j') | no next file with comments »
@@ -809,7 +813,8 @@ const char kFileDescriptorLimit[] = "file-descriptor-limit";
const char kForceAppMode[] = "force-app-mode";
// Displays the First Run experience when the browser is started, regardless of
-// whether or not it's actually the First Run (this overrides kNoFirstRun).
+// whether or not it's actually the First Run (this overrides kNoFirstRun and
+// kCancelFirstRun).
const char kForceFirstRun[] = "force-first-run";
// Tries to load cloud policy for every signed in user, regardless of whether

Powered by Google App Engine
This is Rietveld 408576698